function [peaks, times] = gfp_peaks(data)
% GFP_PEAKS(data) takes input data (samples x channels) and extracts the
% local peaks of the GFP curve, excluding starts and ends of epochs.
% 
%   Inputs:
%       data     =     Input data (samples x channels)
%
%   Outputs:
%       peaks    =     Array with all GFP peaks. Each cell has dimensions
%                      (peaks x channels).
%       times    =     Array with the time points of all GFP peaks.
%                      Each cell has dimensions (times x 1)


[~,locs] = findpeaks(double(std(data,0,2)));
peaks = data(locs,:);
times = locs;

end

